#!/bin/bash

###########################################
# Screen Stream Mirroring service install #
###########################################

echo "*** Screen Stream Mirroring service setup v19 ***"
#
cd "$(dirname "$0")"
chmod 0777 ./tools/adb
adb="./tools/adb -d"
fullVersion="com.mobzapp.screenstream"
trialVersion="com.mobzapp.screenstream.trial"

# Check whether device is connected or wait for one
adbState=$($adb get-state)
if [[ $adbState == "device" ]]; then
    echo "Device not found -- connect one to continue..."
    $adb wait-for-device
    echo "Device connected."
    
    # find installed version of ScreenStream
	checkApp=$($adb shell pm path $fullVersion)
	if [[ $checkApp != "" ]]; then
		version=$fullVersion
	else
		checkApp=$($adb shell pm path $trialVersion)
		if [[ $checkApp != "" ]]; then
			version=$trialVersion
		else
			version=""
		fi
	fi

	if [ ! -z $version ]; then
		# Stop application
		echo "Stopping Screen Stream Mirroring application..."
		$adb shell "am force-stop "$trialVersion
		$adb shell "am kill "$trialVersion
		$adb shell "am force-stop "$fullVersion
		$adb shell "am kill "$fullVersion
		# Stop the service
		$adb shell killall -9 ScreenStreamServerNR >/dev/null
		# Stop also the new service
		$adb shell killall -9 ScreenStreamEncServer >/dev/null
		echo "Starting Screen Stream Mirroring service..."
		# Start the service
		$adb shell "/data/data/"$version"/files/ScreenStreamServerNR; cp /data/data/"$version"/files/ScreenStreamServerNR /data/local/tmp/; /data/local/tmp/ScreenStreamServerNR" >/dev/null &
		# Start also the new service
		$adb shell "/data/data/"$version"/files/ScreenStreamEncServer; cp /data/data/"$version"/files/ScreenStreamEncServer /data/local/tmp/; /data/local/tmp/ScreenStreamEncServer" >/dev/null &
		# Start application
		echo "Restarting Screen Stream Mirroring application..."
		$adb shell "am start -n "$version"/com.mobzapp.screenstream.StartupSplashActivity" >/dev/null &
	else
		echo "*** Application not found! Please check Screen Stream Mirroring installation, and be sure you unzipped the entire ZIP content ***"
	fi
    
else
	echo
	echo "Device not found:"
	echo
	echo "1. Check you enabled USB debugging option (read Instructions.txt if needed) and (re)plug device to USB."
	echo
	echo "2. Check you authorized the computer for USB debugging if a confirmation dialog appeared on your Android device."
	echo
	echo "3. Check you unzipped the entire ZIP file content."
	echo
fi
